@@ -2,7 +2,7 @@
 # ----------------------------------------------------------------------------------------------------------
 #  Copyright 2003-2007 Alex Peeters [alex.peeters@citap.be]
 # ----------------------------------------------------------------------------------------------------------
-# 2007/06/10, v3.000.014, holidayBundleSetDowntimes.sh
+# 2007/10/21, v3.000.015, holidayBundleSetDowntimes.sh
 # ----------------------------------------------------------------------------------------------------------
 
 if [ -f ~/.profile ]; then
@@ -13,6 +13,10 @@ if [ -f ~/.bash_profile ]; then
   source ~/.bash_profile
 fi
 
-AMPATH=/opt/asnmtap-3.000.xxx/applications/bin
+AMPATH=/opt/asnmtap-3.000.xxx
 
-cd $AMPATH; /usr/local/bin/perl holidayBundleSetDowntimes.pl
+if [ "$ASNMTAP_PATH" ]; then
+  AMPATH=$ASNMTAP_PATH
+fi
+
+cd $AMPATH/applications/bin; /usr/local/bin/perl holidayBundleSetDowntimes.pl
