@@ -2,7 +2,7 @@
 # ---------------------------------------------------------------------------------------------------------
 #  Copyright 2003-2007 Alex Peeters [alex.peeters@citap.be]
 # ---------------------------------------------------------------------------------------------------------
-# 2007/06/10, v3.000.014, contact.pl for ASNMTAP::Asnmtap::Applications::CGI
+# 2007/10/21, v3.000.015, contact.pl for ASNMTAP::Asnmtap::Applications::CGI
 # ----------------------------------------------------------------------------------------------------------
 
 use strict;
@@ -20,7 +20,7 @@ use DBI;
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-use ASNMTAP::Asnmtap::Applications::CGI v3.000.014;
+use ASNMTAP::Asnmtap::Applications::CGI v3.000.015;
 use ASNMTAP::Asnmtap::Applications::CGI qw(:APPLICATIONS :CGI);
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -31,18 +31,18 @@ use vars qw($PROGNAME);
 
 $PROGNAME       = "contact.pl";
 my $prgtext     = "$APPLICATION Contact Server Administrators";
-my $version     = do { my @r = (q$Revision: 3.000.014$ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r }; # must be all on one line or MakeMaker will get confused.
+my $version     = do { my @r = (q$Revision: 3.000.015$ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r }; # must be all on one line or MakeMaker will get confused.
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
 # URL Access Parameters
 my $cgi = new CGI;
-my $pagedir  = (defined $cgi->param('pagedir')) ? $cgi->param('pagedir') : "index"; $pagedir =~ s/\+/ /g;
-my $pageset  = (defined $cgi->param('pageset')) ? $cgi->param('pageset') : "index-cv"; $pageset =~ s/\+/ /g;
-my $debug    = (defined $cgi->param('debug'))   ? $cgi->param('debug')   : "F";
-my $action   = (defined $cgi->param('action'))  ? $cgi->param('action')  : "sendView";
-my $Csubject = (defined $cgi->param('subject')) ? $cgi->param('subject') : "";
-my $Cmessage = (defined $cgi->param('message')) ? $cgi->param('message') : "";
+my $pagedir  = (defined $cgi->param('pagedir')) ? $cgi->param('pagedir') : 'index'; $pagedir =~ s/\+/ /g;
+my $pageset  = (defined $cgi->param('pageset')) ? $cgi->param('pageset') : 'index-cv'; $pageset =~ s/\+/ /g;
+my $debug    = (defined $cgi->param('debug'))   ? $cgi->param('debug')   : 'F';
+my $action   = (defined $cgi->param('action'))  ? $cgi->param('action')  : 'sendView';
+my $Csubject = (defined $cgi->param('subject')) ? $cgi->param('subject') : '';
+my $Cmessage = (defined $cgi->param('message')) ? $cgi->param('message') : '';
 
 my ($pageDir, $environment) = split (/\//, $pagedir, 2);
 $environment = 'P' unless (defined $environment);
@@ -53,7 +53,7 @@ my $htmlTitle = $APPLICATION .' - '. $ENVIRONMENT{$environment};
 my ($nextAction, $submitButton, $sendMessage);
 
 # User Session and Access Control
-my ($sessionID, $iconAdd, $iconDelete, $iconDetails, $iconEdit, $iconQuery, $iconTable, $errorUserAccessControl, undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, $subTiltle) = user_session_and_access_control (0, 'guest', $cgi, $pagedir, $pageset, $debug, $htmlTitle, "Contact", undef);
+my ($sessionID, $iconAdd, $iconDelete, $iconDetails, $iconEdit, $iconQuery, $iconTable, $errorUserAccessControl, undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, undef, $subTitle) = user_session_and_access_control (0, 'guest', $cgi, $pagedir, $pageset, $debug, $htmlTitle, "Contact", undef);
 
 # Serialize the URL Access Parameters into a string
 my $urlAccessParameters = "pagedir=$pagedir&pageset=$pageset&debug=$debug&CGISESSID=$sessionID&subject=$Csubject&message=$Cmessage";
@@ -62,11 +62,11 @@ my $urlAccessParameters = "pagedir=$pagedir&pageset=$pageset&debug=$debug&CGISES
 print "<pre>pagedir       : $pagedir<br>pageset       : $pageset<br>debug         : $debug<br>CGISESSID     : $sessionID<br>subject       : $Csubject<br>message       : $Cmessage<br>URL ...       : $urlAccessParameters</pre>" if ( $debug eq 'T' );
 
 if ( defined $sessionID and ! defined $errorUserAccessControl ) {
-  if ($action eq "sendView") {
+  if ($action eq 'sendView') {
     $htmlTitle    = "Send contact email";
     $submitButton = "Send";
     $nextAction   = "send";
-  } elsif ($action eq "send") {
+  } elsif ($action eq 'send') {
     my $tDebug = ($debug eq 'T') ? 2 : 0;
     my $returnCode = sending_mail ( $SERVERLISTSMTP, $SENDEMAILTO, $SENDMAILFROM, "$APPLICATION / $Csubject", $Cmessage, $tDebug );
     $sendMessage = ( $returnCode ? "Email succesfully send to the '$APPLICATION' server administrators" : "Problem sending email to the '$APPLICATION' server administrators" );
@@ -74,9 +74,9 @@ if ( defined $sessionID and ! defined $errorUserAccessControl ) {
 
   # HTML  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-  print_header (*STDOUT, $pagedir, $pageset, $htmlTitle, $subTiltle, 3600, '', 'F', '', $sessionID);
+  print_header (*STDOUT, $pagedir, $pageset, $htmlTitle, $subTitle, 3600, '', 'F', '', $sessionID);
 
-  if ($action eq "sendView") {
+  if ($action eq 'sendView') {
     print <<HTML;
     <form action="$ENV{SCRIPT_NAME}" method="post" name="contact">
       <input type="hidden" name="pagedir"   value="$pagedir">
@@ -93,7 +93,7 @@ HTML
     <tr align="center"><td><table border="0" cellspacing="0" cellpadding="0">
 HTML
 
-  if ($action eq "sendView") {
+  if ($action eq 'sendView') {
   print <<HTML;
       <tr><td><b>Subject: </b>&nbsp;</td><td><input type="text" name="subject" value="$Csubject" size="108" maxlength="108"></td></tr>
       <tr><td valign="top"><b>Message: </b>&nbsp;</td><td><textarea name=message cols=84 rows=13>$Cmessage</textarea></td></tr>
@@ -104,7 +104,7 @@ HTML
   }
 
   print "    </table>\n      </td></tr></table>\n  <br>\n";
-  print "      </form>" if ($action eq "sendView");
+  print "      </form>" if ($action eq 'sendView');
 }
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
